# CLAMR - FFMPEG workflow using CWL

This workflow uses the DockerRequirements dockerFile and beeflow:containerNameto build the clamr and ffmpeg in a container.

```
clamr_wf.cwl - the main cwl  
calmr_job.yml - yaml file for values used by the cwl files   
clamr.cwl - cwl file for the clamr step
ffmpeg.cwl - cwl file for the ffmpeg step
```



